@@ -33,7 +33,7 @@
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL.php,v 1.11 2007/01/28 07:13:59 seasonstream Exp $
+ * @version   CVS: $Id: SyL.php,v 1.12 2007/02/03 11:44:45 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -41,7 +41,7 @@
 /**
  * С
  */
-define('SYL_VERSION', '0.8.1');
+define('SYL_VERSION', '0.8.2');
 
 /**
  * ١ǥ쥯ȥ
@@ -52,11 +52,11 @@ define('SYL_INCLUDE_DIR', SYL_DIR . '/include');
 /**
  * PHPƥ२顼¸ե饰
  */
-define('SYL_CONFIG_SYSTEM_ERROR_LOG', true);
+define('SYL_ERROR_SYSTEM_LOG', true);
 /**
  * PHPƥ२顼¸ե
  */
-define('SYL_CONFIG_SYSTEM_ERROR_LOG_FILE', SYL_DIR . '/var/syslogs/phperror_' . date('Ymd') . '.log');
+define('SYL_ERROR_SYSTEM_LOG_FILE', SYL_DIR . '/var/syslogs/phperror_' . date('Ymd') . '.log');
 
 /**
  * ǥХå٥
@@ -74,6 +74,7 @@ define('SYL_LOG_DEBUG', 8191); // = E_ALL
 define('SYL_ENCODE_INTERNAL', 'EUC-JP');
 define('SYL_ENCODE_MAIL',     'ISO-2022-JP');
 define('SYL_ENCODE_AJAX',     'UTF-8');
+define('SYL_ENCODE_XML',      'UTF-8');
 
 
 
