@@ -27,7 +27,7 @@
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_Error.php,v 1.13 2007/01/28 07:12:48 seasonstream Exp $
+ * @version   CVS: $Id: SyL_Error.php,v 1.14 2007/02/03 11:44:45 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -39,7 +39,7 @@
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_Error.php,v 1.13 2007/01/28 07:12:48 seasonstream Exp $
+ * @version   CVS: $Id: SyL_Error.php,v 1.14 2007/02/03 11:44:45 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_Error
@@ -330,7 +330,7 @@ class SyL_Error
      */
     function sendMail()
     {
-        if (($this->controller->getErrorNo() <= SYL_DEBUG) && SYL_ERROR_MAIL && (SYL_ADMIN_MAIL_ADDRESS != '')) {
+        if (($this->controller->getErrorNo() <= SYL_DEBUG) && SYL_ERROR_MAIL && (SYL_MAIL_ADMIN_ADDRESS != '')) {
             // ռ
             $date = date('Y-m-d H:i:s');
             // С̾
@@ -365,8 +365,8 @@ EOF;
             list($type) = explode(':', SYL_MAIL_TYPE, 2);
             $mail =& SyL_Mail::getObject($type);
             $mail->setSubject($error_mail_subject);
-            $mail->setFrom(SYL_ADMIN_MAIL_ADDRESS);
-            $mail->addTo(SYL_ADMIN_MAIL_ADDRESS);
+            $mail->setFrom(SYL_MAIL_ADMIN_ADDRESS);
+            $mail->addTo(SYL_MAIL_ADMIN_ADDRESS);
             $mail->setBody($error_mail_body);
             if (!$mail->send()) {
                 SyL_Loggers::error($mail->getErrorMessage());
