@@ -27,7 +27,7 @@
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_Response.php,v 1.4 2007/01/21 08:12:34 seasonstream Exp $
+ * @version   CVS: $Id: SyL_Response.php,v 1.5 2007/02/03 11:44:45 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -39,7 +39,7 @@
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_Response.php,v 1.4 2007/01/21 08:12:34 seasonstream Exp $
+ * @version   CVS: $Id: SyL_Response.php,v 1.5 2007/02/03 11:44:45 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_Response
@@ -95,8 +95,8 @@ class SyL_Response
         SyL_Loggers::info("[Response] 404 Not Found - {$request_uri}");
 
         SyL_Response::setStatusHeader('404');
-        if (defined('SYL_RESPONSE_URL_404') && SYL_RESPONSE_URL_404) {
-            SyL_Response::redirect(SYL_RESPONSE_URL_404);
+        if (defined('SYL_ERROR_URL_404') && SYL_ERROR_URL_404) {
+            SyL_Response::redirect(SYL_ERROR_URL_404);
         } else {
             echo "<h2>HTTP/1.0 404 Not Found</h2>";
             exit;
